# server
workspace_id = 'wsp51aee96517063914'
# core 1
core_id_1 = 'cre51aeeb329c8d730d'
view_id_1 = 'viw51af07c50a0969e0'
table_id_1 = 'tbl51aeee11660d81c8'
column_id_1 = 'col51afae2e078653a5'
column_name_1 = 'col_name1'
view_name_1 = 'viewname'
row_id_1 = 'row51af93a17a8bfe75'
core_name_1 = 'test_pysdk'

# # local
# workspace_id = 'wspb595e72fbb8ef9bd'
# # core 1
# core_id_1 = 'creb595e72fd00a840d'
# view_id_1 = 'viwb595e731b801592d'
# table_id_1 = 'tblb595e7303809d5c3'
# column_id_1 = 'colb5957e93a08baf08'
# column_name_1 = 'col_name1'
# view_name_1 = 'viewname'
# row_id_1 = 'rowb5957e920a816926'
# core_name_1 = 'test_pysdk'

sleep_number = 10
sleep_time = 0.1
